from distutils.core import setup
setup(
  name = 'pjira',
  packages = ['pjira'], # this must be the same as the name above
  version = '0.1',
  description = 'A simple Atlassian jira cli client written in python',
  author = 'Shubham Sharma',
  author_email = 'shubham.sha12@gmail.com',
  url = 'https://github.com/gabber12/python-jira', # use the URL to the github repo
  download_url = 'https://github.com/gabber12/python-jira/archive/0.1.1.tar.gz', # I'll explain this in a second
  keywords = ['client', 'cli', 'jira'], # arbitrary keywords
  classifiers = [],
)
